@@ -17,18 +17,18 @@ def init_dataframe(args, input_file, sub_type):
     df.replace(check_na, np.nan, inplace=True)
 
     if sub_type == 'imau/ant':
-        temperature_keys = ['temp_cnr1', 'air_temp',
-                            'snow_temp_1a', 'snow_temp_2a', 'snow_temp_3a', 'snow_temp_4a', 'snow_temp_5a',
-                            'snow_temp_1b', 'snow_temp_2b', 'snow_temp_3b', 'snow_temp_4b', 'snow_temp_5b',
+        temperature_keys = ['temp_cnr1', 'ta',
+                            'tsn1a', 'tsn2a', 'tsn3a', 'tsn4a', 'tsn5a',
+                            'tsn1b', 'tsn2b', 'tsn3b', 'tsn4b', 'tsn5b',
                             'temp_logger']
 
     elif sub_type == 'imau/grl':
-        temperature_keys = ['temp_cnr1', 'air_temp2', 'air_temp6',
-                            'snow_temp_1', 'snow_temp_2', 'snow_temp_3', 'snow_temp_4', 'snow_temp_5',
+        temperature_keys = ['temp_cnr1', 'ta2', 'ta6',
+                            'tsn1', 'tsn2', 'tsn3', 'tsn4', 'tsn5',
                             'datalogger']
 
     df.loc[:, temperature_keys] += common.freezing_point_temp
-    df.loc[:, 'air_pressure'] *= common.pascal_per_millibar
+    df.loc[:, 'pa'] *= common.pascal_per_millibar
     df = df.where((pd.notnull(df)), common.get_fillvalue(args))
 
     return df
